@@ -1,4 +1,4 @@
-import seutils
+import seutils, os
 from seutils import run_command, get_exitcode, Inode, split_mgm, N_COPY_RETRIES
 import os.path as osp
 logger = seutils.logger
